@@ -15,6 +15,10 @@ class infix:
         return self.function(value1, value2)
 
 def _is_in(x, y):
-    return np.max([(np.array(list(x)) == np.array(list(y[i:i+len(x)]))).sum() / len(x) for i in range(len(y) - len(x))])
+    pl = [(np.array(list(x)) == np.array(list(y[i:i+len(x)]))).sum() / len(x) for i in range(len(y) - len(x))]
+    if len(pl) > 0:
+        return np.max(pl)
+    else:
+        return 0
 
 match_in = infix(lambda x,y: _is_in(x, y) > 0.5)
\ No newline at end of file
